Analysis settings

analysis_settings.json controls how a single analysis is run — the number of samples, the model settings selections, and which outputs (summaries and ORD tables) to produce. It is validated by ods_tools against analysis_settings_schema.json. Nested objects (e.g. gul_summaries, and its ord_output) are expanded into their own subsections below.

The ord_output flags select which result tables to produce; each maps to a table in the ORD standard (e.g. ept_full_uncertainty_oep → the EPT, elt_sample → the SELT).

Field

Type

Required

Constraints

Description

version

string

minimum 3

The schema version for analysis settings validation (optional)

oed_version

string

The OED schema version of the file - ‘major, minor, patch’ format i.e. (2.0.0 or v2.0.0 or “latest version”)

source_tag

integer / string

Labels the origin of the analysis.

analysis_tag

integer / string

Labels the analysis with an identifier.

model_supplier_id

string

Yes

Identifier for the model vendor/module supplier.

model_name_id

string

Yes

Identifier for the model.

number_of_samples

integer

default 100; minimum 0

The number of samples generated per event.

gul_threshold

number

default 0; minimum 0

The threshold at which groun-up losses will be capped.

return_periods

array[integer]

List of return periods as integers ‘[10, 100, 1000 .. etc]’

event_ids

array[integer]

List of event ids as integers ‘[1, 5, 123 .. etc]’

event_ranges

string

Comma separated ist of event id ranges using hyphens as string ‘1-4,8,89-94 .. etc’

peril_filter

array[string]

List of OED peril ids ‘[‘WSS’, ‘WTC’ .. ]’

quantiles

array[number]

List of quantiles as float values ‘[0.0, 0.2, 0.4 .. etc]’

computation_settings

object

List of oasislmf package settings, options are dependent on the package version. To see these look at releases 2.4.0 and up (https://github.com/OasisLMF/OasisLMF/releases)

model_settings

object

Yes

Model specific settings.

vulnerability_adjustments

object

Object containing vulnerability adjustments and replacements.

join_summary_info

boolean

default False

If true, joins the summary info file data to any output files generated

gul_output

boolean

default False

If true generate ground-up loss outputs as per specified gul-summaries.

gul_summaries

array[object]

Specified which outputs should be generated for which summary sets, for insured losses.

il_output

boolean

default False

If true generate insured loss outputs as per specified il-summaries.

il_summaries

array[object]

Specified which outputs should be generated for which summary sets, for insured losses.

ri_output

boolean

default False

If true generate reinsurance net loss outputs as per specified ri-summaries.

ri_summaries

array[object]

Specified which outputs should be generated for which summary sets, for insured losses.

ri_inuring_priorities

array[integer]

Request output at intervening inuring priorities specified as list of integers ‘[1, 3, 4 .. etc]’

rl_output

boolean

default False

If true generate all the reinsurance loss outputs as per specified rl-summaries.

rl_summaries

array[object]

Specified which outputs should be generated for which summary sets, for insured losses.

rl_inuring_priorities

array[integer]

Request output at intervening inuring priorities specified as list of integers ‘[1, 3, 4 .. etc]’

full_correlation

boolean

default False

If true generate losses for fully correlated output, i.e. no independence between groups, in addition to losses for default output.

pla

boolean

default False

If true apply post loss amplification/reduction to losses.

do_disaggregation

boolean

default True

Set whether to split terms and conditions for aggregate exposure (optional)

pla_secondary_factor

number

default 1; minimum 0; maximum 1

Secondary factor to apply to post loss amplification/reduction factors.

pla_uniform_factor

number

default 0; minimum 0

Uniform factor to apply across all losses.

model_settings

Model specific settings.

Field

Type

Required

Constraints

Description

use_random_number_file

boolean

If true use a pre-generated set of random number, if false generate random numbers dynamically.

event_set

string

default 1

Identifier for the event set file that is used for output calculations.

event_rates_set

string

default 1

Identifier for the event rates set file that is used for output calculations.

event_occurrence_id

string

default 1

Identifier for the event occurrence file that is used for output calculations.

footprint_set

string

default 1

Identifier for the footprint files that are used for output calculations.

vulnerability_set

string

default 1

Identifier for the vulnerability files that are used for output calculations.

pla_loss_factors_set

string

default 1

Identifier for the Lossfactor file used for PLA (Post Loss amplification).

correlation_settings

array[object]

The Correlation Settings

model_settings.correlation_settings

Field

Type

Required

Constraints

Description

peril_correlation_group

integer

The Peril Correlation Group

hazard_correlation_value

string

The Correlation Value for harard sampling

damage_correlation_value

string

The Correlation Value for vulnerability sampling

vulnerability_adjustments

Object containing vulnerability adjustments and replacements.

Field

Type

Required

Constraints

Description

adjustments

object

Dictionary containing vulnerability adjustments with vulnerability ID as integer keys and adjustment factors as float values.

replace_data

object

Detailed vulnerability replacements.

replace_file

string

Path to a CSV file containing vulnerability data to be replaced.

gul_summaries

Field

Type

Required

Constraints

Description

id

integer

Yes

minimum 1

Identifier for the summary set.

oed_fields

array[string]

A list of OED fields used to group the generated losses.

summarycalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output summary calculations by level for the summary set.

eltcalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the event loss table by level for the summary set.

aalcalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the average annual loss by level for the summary set.

aalcalcmeanonly

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the average annual loss by level for the summary set without calculating the standard deviation.

pltcalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the period loss table by level for the summary set.

lec_output

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output loss exceed curves by level for the summary set.

leccalc

object

Legacy - (oasis 2.4.x and older) Specifies which loss exceedence curve types will be outputed for the summary level

ord_output

object

ORD output settings

gul_summaries.leccalc

Legacy - (oasis 2.4.x and older) Specifies which loss exceedence curve types will be outputed for the summary level

Field

Type

Required

Constraints

Description

return_period_file

boolean

default False

Legacy - (oasis 2.4.x and older) If true, a file listing the return periods will be provided as part of the analysis inputs. If false, a default set will be used.

full_uncertainty_aep

boolean

default True

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the full uncertainty aggregate loss exceedence curve by level for the summary set.

full_uncertainty_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the full uncertainty occurrence loss exceedence curve by level for the summary set.

wheatsheaf_aep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf aggregate loss exceedence curve by level for the summary set.

wheatsheaf_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf occurrence loss exceedence curve by level for the summary set.

wheatsheaf_mean_aep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf mean aggregate loss exceedence curve by level for the summary set.

wheatsheaf_mean_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf occurrence loss exceedence curve by level for the summary set.

sample_mean_aep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the sample mean aggregate loss exceedence curve by level for the summary set.

sample_mean_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the sample occurrence loss exceedence curve by level for the summary set.

gul_summaries.ord_output

ORD output settings

Field

Type

Required

Constraints

Description

elt_sample

boolean

default False

Sample Event Loss Table (ORD Output flag)

elt_quantile

boolean

default False

Quantile Event Loss Table (ORD Output flag)

elt_moment

boolean

default False

Moment Event Loss Table (ORD Output flag)

plt_sample

boolean

default False

Sample Period Loss Table (ORD Output flag)

plt_quantile

boolean

default False

Quantile Period Loss Table (ORD Output flag)

plt_moment

boolean

default False

Moment Period Loss Table (ORD Output flag)

alt_period

boolean

default False

Period Average Loss Table (ORD Output flag)

alt_meanonly

boolean

default False

Average Loss Table with no standard deviation calculation (ORD Output flag)

alct_convergence

boolean

default False

Average Loss Convergence Table (ORD Output flag), requires alt_period set to true

alct_confidence

number

default 0.95; minimum 0.0; maximum 1.0

Set confidence level for ALCT

ept_full_uncertainty_aep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_full_uncertainty_oep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_mean_sample_aep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_mean_sample_oep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_per_sample_mean_aep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_per_sample_mean_oep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

psept_aep

boolean

default False

Per Sample Exceedance Probability Table, (option) when enable this metric is added to the PSEPT file

psept_oep

boolean

default False

Per Sample Exceedance Probability Table (option), when enable this metric is added to the PSEPT file

return_period_file

boolean

default False

If true, a file listing the return periods will be used for EPT and PSEPT files. If false, a default set will be used.

parquet_format

boolean

default False

Write output files in parquet format rather than csv format.

il_summaries

Field

Type

Required

Constraints

Description

id

integer

Yes

minimum 1

Identifier for the summary set.

oed_fields

array[string]

A list of OED fields used to group the generated losses.

summarycalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output summary calculations by level for the summary set.

eltcalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the event loss table by level for the summary set.

aalcalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the average annual loss by level for the summary set.

aalcalcmeanonly

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the average annual loss by level for the summary set without calculating the standard deviation.

pltcalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the period loss table by level for the summary set.

lec_output

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output loss exceed curves by level for the summary set.

leccalc

object

Legacy - (oasis 2.4.x and older) Specifies which loss exceedence curve types will be outputed for the summary level

ord_output

object

ORD output settings

il_summaries.leccalc

Legacy - (oasis 2.4.x and older) Specifies which loss exceedence curve types will be outputed for the summary level

Field

Type

Required

Constraints

Description

return_period_file

boolean

default False

Legacy - (oasis 2.4.x and older) If true, a file listing the return periods will be provided as part of the analysis inputs. If false, a default set will be used.

full_uncertainty_aep

boolean

default True

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the full uncertainty aggregate loss exceedence curve by level for the summary set.

full_uncertainty_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the full uncertainty occurrence loss exceedence curve by level for the summary set.

wheatsheaf_aep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf aggregate loss exceedence curve by level for the summary set.

wheatsheaf_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf occurrence loss exceedence curve by level for the summary set.

wheatsheaf_mean_aep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf mean aggregate loss exceedence curve by level for the summary set.

wheatsheaf_mean_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf occurrence loss exceedence curve by level for the summary set.

sample_mean_aep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the sample mean aggregate loss exceedence curve by level for the summary set.

sample_mean_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the sample occurrence loss exceedence curve by level for the summary set.

il_summaries.ord_output

ORD output settings

Field

Type

Required

Constraints

Description

elt_sample

boolean

default False

Sample Event Loss Table (ORD Output flag)

elt_quantile

boolean

default False

Quantile Event Loss Table (ORD Output flag)

elt_moment

boolean

default False

Moment Event Loss Table (ORD Output flag)

plt_sample

boolean

default False

Sample Period Loss Table (ORD Output flag)

plt_quantile

boolean

default False

Quantile Period Loss Table (ORD Output flag)

plt_moment

boolean

default False

Moment Period Loss Table (ORD Output flag)

alt_period

boolean

default False

Period Average Loss Table (ORD Output flag)

alt_meanonly

boolean

default False

Average Loss Table with no standard deviation calculation (ORD Output flag)

alct_convergence

boolean

default False

Average Loss Convergence Table (ORD Output flag), requires alt_period set to true

alct_confidence

number

default 0.95; minimum 0.0; maximum 1.0

Set confidence level for ALCT

ept_full_uncertainty_aep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_full_uncertainty_oep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_mean_sample_aep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_mean_sample_oep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_per_sample_mean_aep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_per_sample_mean_oep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

psept_aep

boolean

default False

Per Sample Exceedance Probability Table, (option) when enable this metric is added to the PSEPT file

psept_oep

boolean

default False

Per Sample Exceedance Probability Table (option), when enable this metric is added to the PSEPT file

return_period_file

boolean

default False

If true, a file listing the return periods will be used for EPT and PSEPT files. If false, a default set will be used.

parquet_format

boolean

default False

Write output files in parquet format rather than csv format.

ri_summaries

Field

Type

Required

Constraints

Description

id

integer

Yes

minimum 1

Identifier for the summary set.

oed_fields

array[string]

A list of OED fields used to group the generated losses.

summarycalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output summary calculations by level for the summary set.

eltcalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the event loss table by level for the summary set.

aalcalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the average annual loss by level for the summary set.

aalcalcmeanonly

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the average annual loss by level for the summary set without calculating the standard deviation.

pltcalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the period loss table by level for the summary set.

lec_output

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output loss exceed curves by level for the summary set.

leccalc

object

Legacy - (oasis 2.4.x and older) Specifies which loss exceedence curve types will be outputed for the summary level

ord_output

object

ORD output settings

ri_summaries.leccalc

Legacy - (oasis 2.4.x and older) Specifies which loss exceedence curve types will be outputed for the summary level

Field

Type

Required

Constraints

Description

return_period_file

boolean

default False

Legacy - (oasis 2.4.x and older) If true, a file listing the return periods will be provided as part of the analysis inputs. If false, a default set will be used.

full_uncertainty_aep

boolean

default True

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the full uncertainty aggregate loss exceedence curve by level for the summary set.

full_uncertainty_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the full uncertainty occurrence loss exceedence curve by level for the summary set.

wheatsheaf_aep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf aggregate loss exceedence curve by level for the summary set.

wheatsheaf_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf occurrence loss exceedence curve by level for the summary set.

wheatsheaf_mean_aep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf mean aggregate loss exceedence curve by level for the summary set.

wheatsheaf_mean_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf occurrence loss exceedence curve by level for the summary set.

sample_mean_aep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the sample mean aggregate loss exceedence curve by level for the summary set.

sample_mean_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the sample occurrence loss exceedence curve by level for the summary set.

ri_summaries.ord_output

ORD output settings

Field

Type

Required

Constraints

Description

elt_sample

boolean

default False

Sample Event Loss Table (ORD Output flag)

elt_quantile

boolean

default False

Quantile Event Loss Table (ORD Output flag)

elt_moment

boolean

default False

Moment Event Loss Table (ORD Output flag)

plt_sample

boolean

default False

Sample Period Loss Table (ORD Output flag)

plt_quantile

boolean

default False

Quantile Period Loss Table (ORD Output flag)

plt_moment

boolean

default False

Moment Period Loss Table (ORD Output flag)

alt_period

boolean

default False

Period Average Loss Table (ORD Output flag)

alt_meanonly

boolean

default False

Average Loss Table with no standard deviation calculation (ORD Output flag)

alct_convergence

boolean

default False

Average Loss Convergence Table (ORD Output flag), requires alt_period set to true

alct_confidence

number

default 0.95; minimum 0.0; maximum 1.0

Set confidence level for ALCT

ept_full_uncertainty_aep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_full_uncertainty_oep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_mean_sample_aep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_mean_sample_oep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_per_sample_mean_aep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_per_sample_mean_oep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

psept_aep

boolean

default False

Per Sample Exceedance Probability Table, (option) when enable this metric is added to the PSEPT file

psept_oep

boolean

default False

Per Sample Exceedance Probability Table (option), when enable this metric is added to the PSEPT file

return_period_file

boolean

default False

If true, a file listing the return periods will be used for EPT and PSEPT files. If false, a default set will be used.

parquet_format

boolean

default False

Write output files in parquet format rather than csv format.

rl_summaries

Field

Type

Required

Constraints

Description

id

integer

Yes

minimum 1

Identifier for the summary set.

oed_fields

array[string]

A list of OED fields used to group the generated losses.

summarycalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output summary calculations by level for the summary set.

eltcalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the event loss table by level for the summary set.

aalcalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the average annual loss by level for the summary set.

aalcalcmeanonly

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the average annual loss by level for the summary set without calculating the standard deviation.

pltcalc

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output the period loss table by level for the summary set.

lec_output

boolean

default False

Legacy - (oasis 2.4.x and older) If true, output loss exceed curves by level for the summary set.

leccalc

object

Legacy - (oasis 2.4.x and older) Specifies which loss exceedence curve types will be outputed for the summary level

ord_output

object

ORD output settings

rl_summaries.leccalc

Legacy - (oasis 2.4.x and older) Specifies which loss exceedence curve types will be outputed for the summary level

Field

Type

Required

Constraints

Description

return_period_file

boolean

default False

Legacy - (oasis 2.4.x and older) If true, a file listing the return periods will be provided as part of the analysis inputs. If false, a default set will be used.

full_uncertainty_aep

boolean

default True

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the full uncertainty aggregate loss exceedence curve by level for the summary set.

full_uncertainty_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the full uncertainty occurrence loss exceedence curve by level for the summary set.

wheatsheaf_aep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf aggregate loss exceedence curve by level for the summary set.

wheatsheaf_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf occurrence loss exceedence curve by level for the summary set.

wheatsheaf_mean_aep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf mean aggregate loss exceedence curve by level for the summary set.

wheatsheaf_mean_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the wheatsheaf occurrence loss exceedence curve by level for the summary set.

sample_mean_aep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the sample mean aggregate loss exceedence curve by level for the summary set.

sample_mean_oep

boolean

default False

Legacy - (oasis 2.4.x and older) If true and LEC output is true, output the sample occurrence loss exceedence curve by level for the summary set.

rl_summaries.ord_output

ORD output settings

Field

Type

Required

Constraints

Description

elt_sample

boolean

default False

Sample Event Loss Table (ORD Output flag)

elt_quantile

boolean

default False

Quantile Event Loss Table (ORD Output flag)

elt_moment

boolean

default False

Moment Event Loss Table (ORD Output flag)

plt_sample

boolean

default False

Sample Period Loss Table (ORD Output flag)

plt_quantile

boolean

default False

Quantile Period Loss Table (ORD Output flag)

plt_moment

boolean

default False

Moment Period Loss Table (ORD Output flag)

alt_period

boolean

default False

Period Average Loss Table (ORD Output flag)

alt_meanonly

boolean

default False

Average Loss Table with no standard deviation calculation (ORD Output flag)

alct_convergence

boolean

default False

Average Loss Convergence Table (ORD Output flag), requires alt_period set to true

alct_confidence

number

default 0.95; minimum 0.0; maximum 1.0

Set confidence level for ALCT

ept_full_uncertainty_aep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_full_uncertainty_oep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_mean_sample_aep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_mean_sample_oep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_per_sample_mean_aep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

ept_per_sample_mean_oep

boolean

default False

Exceedance Probability Table (option), when enable this metric is added to the EPT file

psept_aep

boolean

default False

Per Sample Exceedance Probability Table, (option) when enable this metric is added to the PSEPT file

psept_oep

boolean

default False

Per Sample Exceedance Probability Table (option), when enable this metric is added to the PSEPT file

return_period_file

boolean

default False

If true, a file listing the return periods will be used for EPT and PSEPT files. If false, a default set will be used.

parquet_format

boolean

default False

Write output files in parquet format rather than csv format.