Combine settings

Configuration for combining ORD results (combine_settings_schema.json), used when grouping and aggregating result tables across analyses.

Field

Type

Required

Constraints

Description

occ_dtype

array[array]

dtype for records in the occurrence.bin file

group_fill_perspectives

boolean

default False

Enable filling financial perspectives to enable more groupings of output sets.

group_event_set_fields

array[string]

List of fields

group_number_of_periods

integer

Yes

Number of periods for grouping

group_period_seed

integer

default 2479

Seed for the grouping random number generator.

group_correlation

float

Correlation to apply to the group.

group_mean

boolean

default False

Output the grouped mean results.

group_mean_type

enum

one of: 1, 2

Output the grouped mean results.

group_secondary_uncertainty

boolean

default False

Output the grouped results with secondary uncertainty (type 2)

group_parametric_distribution

enum

one of: beta, gamma

The parameteric distribution type to estimate values for from MELT.

group_format_priority

array[string]

Control which format for ELTs is used for loss severity sampling when there are multiple formats available per output set. M = mean, Q = quantile, S = sample. ['M'] means only MELTs will be used for loss sampling. ['Q', 'M'] means that QELT will ber prioritised, falling back to MELT if QELT format is missing.

group_alt

boolean

default False

Output grouped ALT report

group_ept

boolean

default False

Output grouped EPT report

group_ept_oep

boolean

default True

Output grouped EPT with OEP if group_ept

group_ept_aep

boolean

default True

Output grouped EPT with AEP if group_ept

group_plt

boolean

default False

Output grouped PLT report

output_type

string

default csv

Output type for all outputs. Options are ‘csv’ or ‘parquet’