Combine settings¶
Configuration for combining ORD results (combine_settings_schema.json), used when grouping
and aggregating result tables across analyses.
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
array[array] |
dtype for records in the occurrence.bin file |
||
|
boolean |
default |
Enable filling financial perspectives to enable more groupings of output sets. |
|
|
array[string] |
List of fields |
||
|
integer |
Yes |
Number of periods for grouping |
|
|
integer |
default |
Seed for the grouping random number generator. |
|
|
float |
Correlation to apply to the group. |
||
|
boolean |
default |
Output the grouped mean results. |
|
|
enum |
one of: |
Output the grouped mean results. |
|
|
boolean |
default |
Output the grouped results with secondary uncertainty (type 2) |
|
|
enum |
one of: |
The parameteric distribution type to estimate values for from MELT. |
|
|
array[string] |
Control which format for ELTs is used for loss severity sampling when there are multiple formats available per output set. |
||
|
boolean |
default |
Output grouped ALT report |
|
|
boolean |
default |
Output grouped EPT report |
|
|
boolean |
default |
Output grouped EPT with OEP if group_ept |
|
|
boolean |
default |
Output grouped EPT with AEP if group_ept |
|
|
boolean |
default |
Output grouped PLT report |
|
|
string |
default |
Output type for all outputs. Options are ‘csv’ or ‘parquet’ |