Model settings¶
model_settings.json describes a model’s runtime capabilities, lookup configuration and
defaults. It is supplied by the model and validated by ods_tools against
model_settings_schema.json. Nested objects (e.g. model_settings, lookup_settings) are
expanded into their own subsections below.
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
minimum 3 |
The schema version for model settings validation (optional) |
|
|
string |
Name of the model associated with this settings file (optional) |
||
|
string |
Short Description of the catastrophe model (optional) |
||
|
string |
The supplier ID for the model. (optional) |
||
|
string |
The model ID for the model. (optional) |
||
|
string |
The version ID for the model. (optional) |
||
|
enum |
one of: |
OasisPlatform execution mode for running an analysis, V1 = ‘Single server execution’ (worker versions |
|
|
boolean |
Marks this model as a ‘complex model’ with configuration options at the input file generation stage. (optional) |
||
|
integer |
minimum 0 |
The default number of samples generated per event. (optional) |
|
|
object |
Yes |
Runtime settings available to a model |
|
|
object |
Yes |
Model lookup section |
|
|
array[object] |
Legacy Correlation Settings. Now moved to model_settings |
||
|
object |
Additional data options for a model |
||
|
object |
List of parameters that will be passed as arguments to the MDK, options are dependent on the package version. To see these look at releases 2.4.0 and up (https://github.com/OasisLMF/OasisLMF/releases) |
model_settings¶
Runtime settings available to a model
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
object |
The ‘id’ field from options is used as a file suffix’ events_ |
||
|
object |
The ‘id’ from options is used as a file suffix’ occurrence_ |
||
|
object |
The ‘id’ field from options is used as a file suffix, e.g. footprint_ |
||
|
object |
The ‘id’ field from options is used as a file suffix, e.g. vulnerability_ |
||
|
object |
The ‘id’ field from options is used as a file suffix, e.g. lossfactors_ |
||
|
array[string] |
If set, the model only supports the given output perspectives. This can be overridden per event set using the ‘valid_perspectives’ field. ‘gul’: ground up losses, ‘il’: insured losses, ‘ri’: reinsurance net losses, ‘rl’: reinsurance losses at all inuring priorities. |
||
|
array[string] |
If set, the model only supports the given output metrics. This can be overridden per event set using the ‘valid_metrics’ field. Values must match the output options in the summaries section from the |
||
|
array[object] |
The Correlation Settings. |
||
|
object |
Object containing vulnerability adjustments and replacements. |
||
|
boolean |
default |
Legacy - moved to ‘computation_settings’. |
|
|
boolean |
default |
Legacy - moved to ‘computation_settings’ |
|
|
array[string] |
If set, the exposure summary report will include additional breakdowns from the listed fields. Note that the field must exists in the exposure file. |
||
|
array[object] |
Single string paramters |
||
|
array[object] |
List of strings parameters |
||
|
array[object] |
Generic dictionary parameters |
||
|
array[object] |
Boolean parameters |
||
|
array[object] |
Bounded float paramters |
||
|
array[object] |
unbounded numeric paramters |
||
|
array[object] |
Integer paramters |
||
|
array[object] |
Generic dropdown paramters |
||
|
array[object] |
Sets of parameters with pre-assigned values |
||
|
array[object] |
Parameter Groups |
model_settings.event_set¶
The ‘id’ field from options is used as a file suffix’ events_
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
string |
Yes |
Initial setting for event set |
|
|
array[object] |
Yes |
Array of possible event sets |
model_settings.event_set.options¶
Event sets option
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
String value used to select an event set |
|
|
string |
Yes |
UI description for selection |
|
|
integer |
minimum 0 |
The total number of events in the set. (optional) |
|
|
array[string] |
An optional list of viable occurrence file ids to use with this event set |
||
|
array[string] |
An optional list of viable footprint file ids to use with this event set |
||
|
array[string] |
An optional list of viable PLA lossfactors file ids to use with this event set |
||
|
array[string] |
If set, this event set only supports the given output perspectives. ‘gul’: ground up losses, ‘il’: insured losses, ‘ri’: reinsurance net losses, ‘rl’: reinsurance losses at all inuring priorities. |
||
|
array[string] |
If set, this event set only supports the given output metrics, matches the output types set in the summaries section on an |
||
|
string |
Long description (optional) |
model_settings.event_occurrence_id¶
The ‘id’ from options is used as a file suffix’ occurrence_
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
string |
Yes |
Initial setting for occurrence |
|
|
array[object] |
Yes |
Array of possible occurrence sets |
model_settings.event_occurrence_id.options¶
Occurrence set options
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
String value used to select an occurrence set |
|
|
string |
Yes |
UI description for selection |
|
|
string |
Long description (optional) |
||
|
integer |
minimum 1 |
Maximum periods for this occurrence set |
model_settings.footprint_set¶
The ‘id’ field from options is used as a file suffix, e.g. footprint_
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
string |
Yes |
Initial setting for footprint set |
|
|
array[object] |
Yes |
Array of possible footprint sets |
model_settings.footprint_set.options¶
Footprint set options
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
String value used to select a footprint set |
|
|
string |
Yes |
UI description for selection |
|
|
string |
Long description (optional) |
model_settings.vulnerability_set¶
The ‘id’ field from options is used as a file suffix, e.g. vulnerability_
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
string |
Yes |
Initial setting for vulnerability set |
|
|
array[object] |
Yes |
Array of possible vulnerability sets |
model_settings.vulnerability_set.options¶
Vulnerability set options
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
String value used to select a vulnerability set |
|
|
string |
Yes |
UI description for selection |
|
|
string |
Long description (optional) |
model_settings.pla_loss_factors_set¶
The ‘id’ field from options is used as a file suffix, e.g. lossfactors_
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
string |
Yes |
Initial setting for lossfactors set |
|
|
array[object] |
Yes |
Array of possible lossfactors sets |
model_settings.pla_loss_factors_set.options¶
Lossfactors set options
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
String value used to select a lossfactors set |
|
|
string |
Yes |
UI description for selection |
|
|
string |
Long description (optional) |
model_settings.correlation_settings¶
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
integer |
The Peril Correlation Group |
||
|
string |
The Legacy Correlation Value, retained for backward compatibility |
||
|
string |
The Correlation Value for harard sampling |
||
|
string |
The Correlation Value for vulnerability sampling |
model_settings.vulnerability_adjustments¶
Object containing vulnerability adjustments and replacements.
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
object |
Dictionary containing vulnerability adjustments with vulnerability ID as integer keys and adjustment factors as float values. |
||
|
object |
Detailed vulnerability replacements. |
||
|
string |
Path to a CSV file containing vulnerability data to be replaced. |
model_settings.string_parameters¶
User selected string value
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
string |
Yes |
Default ‘string’ for variable |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
model_settings.list_parameters¶
User selected list values
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
array[string] |
Yes |
Default ‘list’ set for variable |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
model_settings.dictionary_parameters¶
User selected dictionarys
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
object |
Yes |
Defaults set for variable |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
model_settings.boolean_parameters¶
User selected boolean option
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
boolean |
Yes |
Default ‘value’ set for variable |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
model_settings.float_parameters¶
Select float value
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
number |
Yes |
Default ‘value’ set for float variable |
|
|
number |
Yes |
Maximum Value for float variable |
|
|
number |
Yes |
Minimum Value for float variable |
|
|
number |
The slider widget’s step interval for adjusting the float parameter. |
||
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
model_settings.numeric_parameters¶
Select float value
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
number |
Yes |
Default integer or float ‘value’ set for variable |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
model_settings.integer_parameters¶
Select float value
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
integer |
Yes |
Default integer ‘value’ set for variable |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
model_settings.dropdown_parameters¶
The ‘id’ field is mapped into the analysis settings as ‘paramter_name’: ‘
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
string |
Yes |
Initial setting for dropdown option |
|
|
array[object] |
Yes |
Array of possible event sets |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
model_settings.dropdown_parameters.options¶
Dropdown option
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
String value used to select an event set |
|
|
string |
Yes |
UI description for selection |
|
|
string |
Long description (optional) |
model_settings.multi_parameter_options¶
Parameter group option
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
object |
Yes |
JSON object holding <parameter_name>: |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
model_settings.parameter_groups¶
Defines which parameter are related
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
Reference for the group element |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
integer |
Yes |
Set which parameter groups to display first |
|
|
array[string] |
Yes |
List of parameters reference by their ‘name’ property |
|
|
boolean |
Boolean to mark if this parameter group is collapsible |
||
|
boolean |
Boolean to mark if parameter group starts collapsed |
lookup_settings¶
Model lookup section
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
array[object] |
Valid Peril codes for this model |
lookup_settings.supported_perils¶
Selection Item
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
OED three letter peril code |
|
|
string |
Yes |
Short string describing the peril |
|
|
integer |
the peril correlated group ID |
correlation_settings¶
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
integer |
The Peril Correlation Group |
||
|
string |
The Correlation Value |
data_settings¶
Additional data options for a model
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
array[string] |
A list of OED releases that this model supports. |
||
|
boolean |
Marks the model as requiring external model data. |
||
|
string |
Version ID of the Model data. |
||
|
string |
Version ID of the lookup keys data. |
||
|
string |
The model worker’s docker image name |
||
|
string |
The model worker’s version ID |
||
|
string |
Version ID of the model documents |
||
|
string |
Version ID of the test files |
||
|
array[string] |
A list of country codes that this model covers. |
||
|
array[string] |
List of OED fields that the model requires. |
||
|
array[object] |
Data assets available to the model |
||
|
array[string] |
List of OED fields from location file to form damage group ids |
||
|
array[string] |
List of OED fields from location file to form hazard group ids |
||
|
array[object] |
Select file_ids from the API endpoint |
data_settings.additional_assets¶
Name, version and location of data
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
Name of the Asset file |
|
|
string |
Version of Asset |
||
|
string |
Filesystem path to the asset |
||
|
string |
Target for deploying this additional asset |
data_settings.datafile_selectors¶
File Selection Parameter
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
name used store the selection under |
|
|
string |
Yes |
UI description for selection |
|
|
string |
Long description (optional) |
||
|
integer |
call to |
||
|
boolean |
Yes |
Allow the user to link multiple files to an analyses. |
|
|
array[object] |
File options filter |
data_settings.datafile_selectors.search_filters¶
Build a query string from the following fields
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
File was uploaded by ‘user’ |
||
|
string |
Filename exactly matches ‘value’ |
||
|
string |
‘value’ is a substring of filename |
||
|
string |
File description matches ‘value’ exactly |
||
|
string |
‘value’ is a substring of a File’s description’ |
||
|
string |
file exactly matches a MIME type |
||
|
string |
A files MIME type contains ‘value’ |
computation_settings¶
List of parameters that will be passed as arguments to the MDK, options are dependent on the package version. To see these look at releases 2.4.0 and up (https://github.com/OasisLMF/OasisLMF/releases)
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
array[object] |
Single string paramters |
||
|
array[object] |
List of strings parameters |
||
|
array[object] |
Generic dictionary parameters |
||
|
array[object] |
Boolean parameters |
||
|
array[object] |
Bounded float paramters |
||
|
array[object] |
unbounded numeric paramters |
||
|
array[object] |
Integer paramters |
||
|
array[object] |
Generic dropdown paramters |
||
|
array[object] |
Sets of parameters with pre-assigned values |
||
|
array[object] |
Parameter Groups |
computation_settings.string_parameters¶
User selected string value
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
string |
Yes |
Default ‘string’ for variable |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
computation_settings.list_parameters¶
User selected list values
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
array[string] |
Yes |
Default ‘list’ set for variable |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
computation_settings.dictionary_parameters¶
User selected dictionarys
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
object |
Yes |
Defaults set for variable |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
computation_settings.boolean_parameters¶
User selected boolean option
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
boolean |
Yes |
Default ‘value’ set for variable |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
computation_settings.float_parameters¶
Select float value
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
number |
Yes |
Default ‘value’ set for float variable |
|
|
number |
Yes |
Maximum Value for float variable |
|
|
number |
Yes |
Minimum Value for float variable |
|
|
number |
The slider widget’s step interval for adjusting the float parameter. |
||
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
computation_settings.numeric_parameters¶
Select float value
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
number |
Yes |
Default integer or float ‘value’ set for variable |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
computation_settings.integer_parameters¶
Select float value
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
integer |
Yes |
Default integer ‘value’ set for variable |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
computation_settings.dropdown_parameters¶
The ‘id’ field is mapped into the analysis settings as ‘paramter_name’: ‘
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
string |
Yes |
Initial setting for dropdown option |
|
|
array[object] |
Yes |
Array of possible event sets |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
computation_settings.dropdown_parameters.options¶
Dropdown option
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
String value used to select an event set |
|
|
string |
Yes |
UI description for selection |
|
|
string |
Long description (optional) |
computation_settings.multi_parameter_options¶
Parameter group option
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
UI name for selection |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
object |
Yes |
JSON object holding <parameter_name>: |
|
|
boolean |
tell if parameter should be visible in UI |
||
|
boolean |
tell if parameter should be editable in UI |
computation_settings.parameter_groups¶
Defines which parameter are related
Field |
Type |
Required |
Constraints |
Description |
|---|---|---|---|---|
|
string |
Yes |
Reference for the group element |
|
|
string |
Yes |
UI description for selection |
|
|
enum |
one of: |
Set if this parameter is ONLY used at input ‘generation’ or for output ‘losses’ |
|
|
string |
Long description (optional) |
||
|
integer |
Yes |
Set which parameter groups to display first |
|
|
array[string] |
Yes |
List of parameters reference by their ‘name’ property |
|
|
boolean |
Boolean to mark if this parameter group is collapsible |
||
|
boolean |
Boolean to mark if parameter group starts collapsed |